@@ -7,6 +7,7 @@ import os
 import logging
 import traceback
 
+from datadog_lambda.extension import use_extension, flush_extension
 from datadog_lambda.cold_start import set_cold_start, is_cold_start
 from datadog_lambda.metric import (
     lambda_stats,
@@ -137,8 +138,11 @@ class _LambdaDecorator(object):
 
     def _after(self, event, context):
         try:
-            if not self.flush_to_log:
+            if not self.flush_to_log or use_extension:
                 lambda_stats.flush(float("inf"))
+            if use_extension:
+                flush_extension()
+
             if self.span:
                 self.span.finish()
             logger.debug("datadog_lambda_wrapper _after() done")
